pub struct TokenBuffer { /* private fields */ }Available on crate feature
parsing only.Expand description
A buffer that can be efficiently traversed multiple times, unlike
TokenStream which requires a deep copy in order to traverse more than
once.
This type is available only if Syn is built with the "parsing" feature.
Implementations
Sourceimpl TokenBuffer
impl TokenBuffer
Sourcepub fn new(stream: TokenStream) -> Self
Available on not (WebAssembly and (target_os=unknown or WASI)) and crate feature proc-macro only.
pub fn new(stream: TokenStream) -> Self
target_os=unknown or WASI)) and crate feature proc-macro only.Creates a TokenBuffer containing all the tokens from the input
proc_macro::TokenStream.
This method is available only if Syn is built with both the "parsing" and
"proc-macro" features.
Sourcepub fn new2(stream: TokenStream) -> Self
pub fn new2(stream: TokenStream) -> Self
Creates a TokenBuffer containing all the tokens from the input
proc_macro2::TokenStream.