Enum AttrStyle

enum AttrStyle

Distinguishes between attributes that decorate an item and attributes that are contained within an item.

Outer attributes

Inner attributes

Variants

Outer
Inner($crate::token::Not)

Implementations

impl Clone for AttrStyle

fn clone(self: &Self) -> Self

impl Copy for AttrStyle

impl Debug for AttrStyle

fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result

impl Eq for AttrStyle

impl Freeze for AttrStyle

impl Hash for AttrStyle

fn hash<H>(self: &Self, state: &mut H)
where
    H: Hasher

impl PartialEq for AttrStyle

fn eq(self: &Self, other: &Self) -> bool

impl RefUnwindSafe for AttrStyle

impl Send for AttrStyle

impl Sync for AttrStyle

impl Unpin for AttrStyle

impl UnsafeUnpin for AttrStyle

impl UnwindSafe for AttrStyle

impl<T> Any for AttrStyle

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for AttrStyle

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for AttrStyle

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for AttrStyle

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for AttrStyle

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for AttrStyle

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for AttrStyle

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for AttrStyle

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for AttrStyle

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>