Enum CapturedParam

enum CapturedParam

Single parameter in a precise capturing bound.

Variants

Lifetime(crate::lifetime::Lifetime)

A lifetime parameter in precise capturing bound: fn f<'a>() -> impl Trait + use<'a>.

Ident(crate::ident::Ident)

A type parameter or const generic parameter in precise capturing bound: fn f<T>() -> impl Trait + use<T> or fn f<const K: T>() -> impl Trait + use<K>.

Implementations

impl Clone for CapturedParam

fn clone(self: &Self) -> Self

impl Debug for CapturedParam

fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result

impl Eq for CapturedParam

impl Freeze for CapturedParam

impl Hash for CapturedParam

fn hash<H>(self: &Self, state: &mut H)
where
    H: Hasher

impl Parse for CapturedParam

fn parse(input: ParseStream<'_>) -> Result<Self>

impl PartialEq for CapturedParam

fn eq(self: &Self, other: &Self) -> bool

impl RefUnwindSafe for CapturedParam

impl Send for CapturedParam

impl Sync for CapturedParam

impl ToTokens for CapturedParam

fn to_tokens(self: &Self, tokens: &mut TokenStream)

impl Unpin for CapturedParam

impl UnsafeUnpin for CapturedParam

impl UnwindSafe for CapturedParam

impl<T> Any for CapturedParam

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for CapturedParam

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for CapturedParam

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for CapturedParam

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for CapturedParam

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Spanned for CapturedParam

fn span(self: &Self) -> Span

impl<T> ToOwned for CapturedParam

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for CapturedParam

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for CapturedParam

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for CapturedParam

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>