[−][src]Enum syn::FloatSuffix
The suffix on a floating point literal if any, like the f32 in
1.0f32.
This type is available if Syn is built with the "derive" or "full"
feature.
Variants
F32F64NoneTrait Implementations
impl Eq for FloatSuffix[src]
impl PartialEq<FloatSuffix> for FloatSuffix[src]
fn eq(&self, other: &FloatSuffix) -> bool[src]
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Clone for FloatSuffix[src]
fn clone(&self) -> FloatSuffix[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]
Performs copy-assignment from source. Read more
impl Hash for FloatSuffix[src]
fn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
H: Hasher,
Feeds a slice of this type into the given [Hasher]. Read more
impl Debug for FloatSuffix[src]