Enum GenericArgument

enum GenericArgument

An individual generic argument, like 'a, T, or Item = T.

Variants

Lifetime(crate::lifetime::Lifetime)

A lifetime argument.

Type(crate::ty::Type)

A type argument.

Const(crate::expr::Expr)

A const expression. Must be inside of a block.

NOTE: Identity expressions are represented as Type arguments, as they are indistinguishable syntactically.

AssocType(AssocType)

A binding (equality constraint) on an associated type: the Item = u8 in Iterator<Item = u8>.

AssocConst(AssocConst)

An equality constraint on an associated constant: the PANIC = false in Trait<PANIC = false>.

Constraint(Constraint)

An associated type bound: Iterator<Item: Display>.

Implementations

impl Clone for GenericArgument

fn clone(self: &Self) -> Self

impl Debug for GenericArgument

fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result

impl Eq for GenericArgument

impl Freeze for GenericArgument

impl Hash for GenericArgument

fn hash<H>(self: &Self, state: &mut H)
where
    H: Hasher

impl Parse for GenericArgument

fn parse(input: ParseStream<'_>) -> Result<Self>

impl PartialEq for GenericArgument

fn eq(self: &Self, other: &Self) -> bool

impl RefUnwindSafe for GenericArgument

impl Send for GenericArgument

impl Sync for GenericArgument

impl ToTokens for GenericArgument

fn to_tokens(self: &Self, tokens: &mut TokenStream)

impl Unpin for GenericArgument

impl UnsafeUnpin for GenericArgument

impl UnwindSafe for GenericArgument

impl<T> Any for GenericArgument

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for GenericArgument

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for GenericArgument

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for GenericArgument

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for GenericArgument

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Spanned for GenericArgument

fn span(self: &Self) -> Span

impl<T> ToOwned for GenericArgument

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for GenericArgument

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for GenericArgument

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for GenericArgument

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>