pub enum GenericMethodArgument {
Type(Type),
Const(Expr),
}Expand description
An individual generic argument to a method, like T.
This type is available only if Syn is built with the "full" feature.
Variants
Type(Type)
A type argument.
Const(Expr)
A const expression. Must be inside of a block.
NOTE: Identity expressions are represented as Type arguments, as they are indistinguishable syntactically.