pub enum TypeParamBound {
Trait(TraitBound),
Lifetime(Lifetime),
}Available on crate features
full or derive only.Expand description
A trait or lifetime used as a bound on a type parameter.
This type is available only if Syn is built with the "derive" or "full"
feature.
Variants
Trait(TraitBound)
Lifetime(Lifetime)