Enum syn::UseTree [−][src]
pub enum UseTree {
Path(UsePath),
Name(UseName),
Rename(UseRename),
Glob(UseGlob),
Group(UseGroup),
}A suffix of an import tree in a use item: Type as Renamed or *.
This type is available if Syn is built with the "full" feature.
Syntax tree enum
This type is a syntax tree enum.
Variants
Path(UsePath)A path prefix of imports in a use item: std::....
This type is available if Syn is built with the "full" feature.
Name(UseName)An identifier imported by a use item: HashMap.
This type is available if Syn is built with the "full" feature.
Rename(UseRename)An renamed identifier imported by a use item: HashMap as Map.
This type is available if Syn is built with the "full" feature.
Glob(UseGlob)A glob import in a use item: *.
This type is available if Syn is built with the "full" feature.
Group(UseGroup)A braced group of imports in a use item: {A, B, C}.
This type is available if Syn is built with the "full" feature.