pub enum WhereClausePlacement {
Early,
Late,
}Available on crate feature
full only.Variants
Early
type Ty<T> where T: 'static = T;
In associated types, this syntax is deprecated in favor of the late placement.
warning: where clause not allowed here
--> src/main.rs
|
| impl Trait for Thing { type Ty<T> where T: 'static = T; }
| ^^^^^^^^^^^^^^^^
= note: see issue #89122 <https://github.com/rust-lang/rust/issues/89122> for more information
= note: `#[warn(deprecated_where_clause_location)]` on by defaultLate
type Ty<T> = T where T: 'static;
In item-level type aliases, this syntax is unstable.
error: where clauses are not allowed after the type for type aliases
--> src/main.rs
|
| type Ty<T> = T where T: 'static;
| ^^^^^^^^^^^^^^^^
= note: see issue #112792 <https://github.com/rust-lang/rust/issues/112792> for more information
= help: add `#![feature(lazy_type_alias)]` to the crate attributes to enableTrait Implementations
Sourceimpl Clone for WhereClausePlacement
impl Clone for WhereClausePlacement
impl Copy for WhereClausePlacement
Sourceimpl Debug for WhereClausePlacement
Available on crate feature extra-traits only.
impl Debug for WhereClausePlacement
Available on crate feature
extra-traits only.impl Eq for WhereClausePlacement
Available on crate feature
extra-traits only.Sourceimpl Hash for WhereClausePlacement
Available on crate feature extra-traits only.
impl Hash for WhereClausePlacement
Available on crate feature
extra-traits only.Auto Trait Implementations
impl Freeze for WhereClausePlacement
impl RefUnwindSafe for WhereClausePlacement
impl Send for WhereClausePlacement
impl Sync for WhereClausePlacement
impl Unpin for WhereClausePlacement
impl UnsafeUnpin for WhereClausePlacement
impl UnwindSafe for WhereClausePlacement