Struct End

struct End

Pseudo-token used for peeking the end of a parse stream.

This type is only useful as an argument to one of the following functions:

The peek will return true if there are no remaining tokens after that point in the parse stream.

Example

Suppose we are parsing attributes containing core::fmt inspired formatting arguments:

and we want to recognize the cases where no interpolation occurs so that more efficient code can be generated.

The following implementation uses input.peek(Token![,]) && input.peek2(End) to recognize the case of a trailing comma without consuming the comma from the parse stream, because if it isn't a trailing comma, that same comma needs to be parsed as part of args.

use proc_macro2::TokenStream;
use quote::quote;
use syn::parse::{End, Parse, ParseStream, Result};
use syn::{parse_quote, Attribute, LitStr, Token};

struct FormatArgs {
    template: LitStr,  // "...{}..."
    args: TokenStream, // , self.x
}

impl Parse for FormatArgs {
    fn parse(input: ParseStream) -> Result<Self> {
        let template: LitStr = input.parse()?;

        let args = if input.is_empty()
            || input.peek(Token![,]) && input.peek2(End)
        {
            input.parse::<Option<Token![,]>>()?;
            TokenStream::new()
        } else {
            input.parse()?
        };

        Ok(FormatArgs {
            template,
            args,
        })
    }
}

fn main() -> Result<()> {
    let attrs: Vec<Attribute> = parse_quote! {
        #[fmt("simple example")]
        #[fmt("interpolation e{}ample", self.x)]
        #[fmt("interpolation e{x}ample")]
    };

    for attr in &attrs {
        let FormatArgs { template, args } = attr.parse_args()?;
        let requires_fmt_machinery =
            !args.is_empty() || template.value().contains(['{', '}']);
        let out = if requires_fmt_machinery {
            quote! {
                ::core::write!(__formatter, #template #args)
            }
        } else {
            quote! {
                __formatter.write_str(#template)
            }
        };
        println!("{}", out);
    }
    Ok(())
}

Implementing this parsing logic without peek2(End) is more clumsy because we'd need a parse stream actually advanced past the comma before being able to find out whether there is anything after it. It would look something like:

# use proc_macro2::TokenStream;
# use syn::parse::{ParseStream, Result};
# use syn::Token;
#
# fn parse(input: ParseStream) -> Result<()> {
use syn::parse::discouraged::Speculative as _;

let ahead = input.fork();
ahead.parse::<Option<Token![,]>>()?;
let args = if ahead.is_empty() {
    input.advance_to(&ahead);
    TokenStream::new()
} else {
    input.parse()?
};
# Ok(())
# }

or:

# use proc_macro2::TokenStream;
# use syn::parse::{ParseStream, Result};
# use syn::Token;
#
# fn parse(input: ParseStream) -> Result<()> {
use quote::ToTokens as _;

let comma: Option<Token![,]> = input.parse()?;
let mut args = TokenStream::new();
if !input.is_empty() {
    comma.to_tokens(&mut args);
    input.parse::<TokenStream>()?.to_tokens(&mut args);
}
# Ok(())
# }

Implementations

impl Clone for End

fn clone(self: &Self) -> Self

impl Copy for End

impl Freeze for End

impl Peek for End

impl RefUnwindSafe for End

impl Send for End

impl Sync for End

impl Unpin for End

impl UnsafeUnpin for End

impl UnwindSafe for End

impl<T> Any for End

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for End

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for End

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for End

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for End

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for End

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> Token for End

fn peek(cursor: Cursor<'_>) -> bool
fn display() -> &'static str

impl<T, U> Into for End

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for End

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for End

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>