pub trait Parse: Sized {
fn parse(input: ParseStream<'_>) -> Result<Self>;
}Expand description
Parsing interface implemented by all types that can be parsed in a default way from a token stream.
Required Methods
source
pub trait Parse: Sized {
fn parse(input: ParseStream<'_>) -> Result<Self>;
}Parsing interface implemented by all types that can be parsed in a default way from a token stream.