Abi

Struct Abi 

pub struct Abi {
    pub extern_token: Extern,
    pub name: Option<LitStr>,
}
Available on crate features derive or full only.
The binary interface of a function: extern "C".

Fields

extern_token: Externname: Option<LitStr>

ABI name is optional, but note that extern blocks and functions with an omitted ABI name are deprecated since Rust 1.86.0. Omitting the ABI after the extern keyword has always implicitly resulted in the “C” ABI. It is now recommended to explicitly specify the “C” ABI (extern "C" {} and extern "C" fn).