ExprGroup

Struct ExprGroup 

pub struct ExprGroup {
    pub attrs: Vec<Attribute>,
    pub group_token: Group,
    pub expr: Box<Expr>,
}
Available on crate features full or derive only.
An expression contained within invisible delimiters.

This variant is important for faithfully representing the precedence of expressions and is related to None-delimited spans in a TokenStream.

This type is available only if Syn is built with the "full" feature.

Fields

attrs: Vec<Attribute>group_token: Groupexpr: Box<Expr>