Struct syn::ExprIfLet [−][src]
pub struct ExprIfLet {
pub attrs: Vec<Attribute>,
pub if_token: If,
pub let_token: Let,
pub pats: Punctuated<Pat, Or>,
pub eq_token: Eq,
pub expr: Box<Expr>,
pub then_branch: Block,
pub else_branch: Option<(Else, Box<Expr>)>,
}An if let expression with an optional else block: if let pat = expr { ... } else { ... }.
The else branch expression may only be an If, IfLet, or
Block expression, not any of the other types of expression.
This type is available if Syn is built with the "full" feature.
Fields
attrs: Vec<Attribute>
if_token: If
let_token: Let
pats: Punctuated<Pat, Or>
eq_token: Eq
expr: Box<Expr>
then_branch: Block
else_branch: Option<(Else, Box<Expr>)>