Struct ExprInfer
struct ExprInfer { ... }
The inferred value of a const generic argument, denoted _.
Fields
attrs: Vec<Attribute>underscore_token: Underscore
Implementations
impl Clone for ExprInfer
fn clone(self: &Self) -> Self
impl Debug for ExprInfer
fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result
impl Eq for ExprInfer
impl Freeze for ExprInfer
impl Hash for ExprInfer
fn hash<H>(self: &Self, state: &mut H) where H: Hasher
impl Parse for ExprInfer
fn parse(input: ParseStream<'_>) -> Result<Self>
impl PartialEq for ExprInfer
fn eq(self: &Self, other: &Self) -> bool
impl RefUnwindSafe for ExprInfer
impl Send for ExprInfer
impl Sync for ExprInfer
impl ToTokens for ExprInfer
fn to_tokens(self: &Self, tokens: &mut TokenStream)
impl Unpin for ExprInfer
impl UnsafeUnpin for ExprInfer
impl UnwindSafe for ExprInfer
impl<T> Any for ExprInfer
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ExprInfer
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ExprInfer
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ExprInfer
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ExprInfer
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Spanned for ExprInfer
fn span(self: &Self) -> Span
impl<T> ToOwned for ExprInfer
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for ExprInfer
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ExprInfer
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ExprInfer
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>