pub struct ExprStruct {
pub attrs: Vec<Attribute>,
pub path: Path,
pub brace_token: Brace,
pub fields: Punctuated<FieldValue, Comma>,
pub dot2_token: Option<Dot2>,
pub rest: Option<Box<Expr>>,
}Expand description
A struct literal expression: Point { x: 1, y: 1 }.
The rest provides the value of the remaining fields as in S { a: 1, b: 1, ..rest }.
This type is available only if Syn is built with the "full" feature.
Fields
attrs: Vec<Attribute>path: Pathbrace_token: Bracefields: Punctuated<FieldValue, Comma>dot2_token: Option<Dot2>rest: Option<Box<Expr>>Trait Implementations
Sourceimpl Clone for ExprStruct
Available on crate feature full only.
impl Clone for ExprStruct
Available on crate feature
full only.Sourceimpl Debug for ExprStruct
Available on crate feature full only.
impl Debug for ExprStruct
Available on crate feature
full only.Sourceimpl From<ExprStruct> for Expr
impl From<ExprStruct> for Expr
Sourcefn from(e: ExprStruct) -> Expr
fn from(e: ExprStruct) -> Expr
Converts to this type from the input type.
Sourceimpl Hash for ExprStruct
Available on crate feature full only.
impl Hash for ExprStruct
Available on crate feature
full only.Sourceimpl Parse for ExprStruct
Available on crate feature full only.
impl Parse for ExprStruct
Available on crate feature
full only.fn parse(input: ParseStream<'_>) -> Result<Self>
Sourceimpl PartialEq for ExprStruct
Available on crate feature full only.
impl PartialEq for ExprStruct
Available on crate feature
full only.Sourceimpl ToTokens for ExprStruct
Available on crate feature full only.
impl ToTokens for ExprStruct
Available on crate feature
full only.Sourcefn to_tokens(&self, tokens: &mut TokenStream)
fn to_tokens(&self, tokens: &mut TokenStream)
Sourcefn to_token_stream(&self) -> TokenStream
fn to_token_stream(&self) -> TokenStream
Sourcefn into_token_stream(self) -> TokenStreamwhere
Self: Sized,
fn into_token_stream(self) -> TokenStreamwhere
Self: Sized,
impl Eq for ExprStruct
Available on crate feature
full only.Auto Trait Implementations
impl Freeze for ExprStruct
impl RefUnwindSafe for ExprStruct
impl !Send for ExprStruct
impl !Sync for ExprStruct
impl Unpin for ExprStruct
impl UnsafeUnpin for ExprStruct
impl UnwindSafe for ExprStruct