Struct FieldPat

struct FieldPat { ... }

A single field in a struct pattern.

Patterns like the fields of Foo { x, ref y, ref mut z } are treated the same as x: x, y: ref y, z: ref mut z but there is no colon token.

Fields

attrs: Vec<Attribute>
member: Member
colon_token: Option<Colon>
pat: Box<Pat>

Implementations

impl Clone for FieldPat

fn clone(self: &Self) -> Self

impl Debug for FieldPat

fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result

impl Eq for FieldPat

impl Freeze for FieldPat

impl Hash for FieldPat

fn hash<H>(self: &Self, state: &mut H)
where
    H: Hasher

impl PartialEq for FieldPat

fn eq(self: &Self, other: &Self) -> bool

impl RefUnwindSafe for FieldPat

impl Send for FieldPat

impl Sync for FieldPat

impl ToTokens for FieldPat

fn to_tokens(self: &Self, tokens: &mut TokenStream)

impl Unpin for FieldPat

impl UnsafeUnpin for FieldPat

impl UnwindSafe for FieldPat

impl<T> Any for FieldPat

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for FieldPat

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for FieldPat

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for FieldPat

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for FieldPat

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Spanned for FieldPat

fn span(self: &Self) -> Span

impl<T> ToOwned for FieldPat

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for FieldPat

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for FieldPat

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for FieldPat

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>