Struct PatIdent
struct PatIdent { ... }
A pattern that binds a new variable: ref mut binding @ SUBPATTERN.
It may also be a unit struct or struct variant (e.g. None), or a
constant; these cannot be distinguished syntactically.
Fields
attrs: Vec<Attribute>by_ref: Option<Ref>mutability: Option<Mut>ident: Identsubpat: Option<(At, Box<Pat>)>
Implementations
impl Clone for PatIdent
fn clone(self: &Self) -> Self
impl Debug for PatIdent
fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result
impl Eq for PatIdent
impl Freeze for PatIdent
impl Hash for PatIdent
fn hash<H>(self: &Self, state: &mut H) where H: Hasher
impl PartialEq for PatIdent
fn eq(self: &Self, other: &Self) -> bool
impl RefUnwindSafe for PatIdent
impl Send for PatIdent
impl Sync for PatIdent
impl ToTokens for PatIdent
fn to_tokens(self: &Self, tokens: &mut TokenStream)
impl Unpin for PatIdent
impl UnsafeUnpin for PatIdent
impl UnwindSafe for PatIdent
impl<T> Any for PatIdent
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for PatIdent
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for PatIdent
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for PatIdent
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for PatIdent
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Spanned for PatIdent
fn span(self: &Self) -> Span
impl<T> ToOwned for PatIdent
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for PatIdent
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for PatIdent
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for PatIdent
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>