Struct PatOr

struct PatOr { ... }

A pattern that matches any one of a set of cases.

Fields

attrs: Vec<Attribute>
leading_vert: Option<Or>
cases: Punctuated<Pat, Or>

Implementations

impl Clone for PatOr

fn clone(self: &Self) -> Self

impl Debug for PatOr

fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result

impl Eq for PatOr

impl Freeze for PatOr

impl Hash for PatOr

fn hash<H>(self: &Self, state: &mut H)
where
    H: Hasher

impl PartialEq for PatOr

fn eq(self: &Self, other: &Self) -> bool

impl RefUnwindSafe for PatOr

impl Send for PatOr

impl Sync for PatOr

impl ToTokens for PatOr

fn to_tokens(self: &Self, tokens: &mut TokenStream)

impl Unpin for PatOr

impl UnsafeUnpin for PatOr

impl UnwindSafe for PatOr

impl<T> Any for PatOr

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for PatOr

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for PatOr

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for PatOr

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for PatOr

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Spanned for PatOr

fn span(self: &Self) -> Span

impl<T> ToOwned for PatOr

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for PatOr

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for PatOr

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for PatOr

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>