Struct Receiver

struct Receiver { ... }

The self argument of an associated method.

If colon_token is present, the receiver is written with an explicit type such as self: Box<Self>. If colon_token is absent, the receiver is written in shorthand such as self or &self or &mut self. In the shorthand case, the type in ty is reconstructed as one of Self, &Self, or &mut Self.

Fields

attrs: Vec<Attribute>
reference: Option<(And, Option<Lifetime>)>
mutability: Option<Mut>
self_token: SelfValue
colon_token: Option<Colon>
ty: Box<Type>

Implementations

impl Receiver

fn lifetime(self: &Self) -> Option<&Lifetime>

impl Clone for Receiver

fn clone(self: &Self) -> Self

impl Debug for Receiver

fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result

impl Eq for Receiver

impl Freeze for Receiver

impl Hash for Receiver

fn hash<H>(self: &Self, state: &mut H)
where
    H: Hasher

impl Parse for Receiver

fn parse(input: ParseStream<'_>) -> Result<Self>

impl PartialEq for Receiver

fn eq(self: &Self, other: &Self) -> bool

impl RefUnwindSafe for Receiver

impl Send for Receiver

impl Sync for Receiver

impl ToTokens for Receiver

fn to_tokens(self: &Self, tokens: &mut TokenStream)

impl Unpin for Receiver

impl UnsafeUnpin for Receiver

impl UnwindSafe for Receiver

impl<T> Any for Receiver

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Receiver

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Receiver

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Receiver

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Receiver

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Spanned for Receiver

fn span(self: &Self) -> Span

impl<T> ToOwned for Receiver

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Receiver

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Receiver

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Receiver

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>