Struct TraitItemConst

struct TraitItemConst { ... }

An associated constant within the definition of a trait.

Fields

attrs: Vec<Attribute>
const_token: Const
ident: Ident
generics: Generics
colon_token: Colon
ty: Type
default: Option<(Eq, Expr)>
semi_token: Semi

Implementations

impl Clone for TraitItemConst

fn clone(self: &Self) -> Self

impl Debug for TraitItemConst

fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result

impl Eq for TraitItemConst

impl Freeze for TraitItemConst

impl Hash for TraitItemConst

fn hash<H>(self: &Self, state: &mut H)
where
    H: Hasher

impl Parse for TraitItemConst

fn parse(input: ParseStream<'_>) -> Result<Self>

impl PartialEq for TraitItemConst

fn eq(self: &Self, other: &Self) -> bool

impl RefUnwindSafe for TraitItemConst

impl Send for TraitItemConst

impl Sync for TraitItemConst

impl ToTokens for TraitItemConst

fn to_tokens(self: &Self, tokens: &mut TokenStream)

impl Unpin for TraitItemConst

impl UnsafeUnpin for TraitItemConst

impl UnwindSafe for TraitItemConst

impl<T> Any for TraitItemConst

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for TraitItemConst

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for TraitItemConst

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for TraitItemConst

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for TraitItemConst

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Spanned for TraitItemConst

fn span(self: &Self) -> Span

impl<T> ToOwned for TraitItemConst

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for TraitItemConst

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for TraitItemConst

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for TraitItemConst

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>