Struct TraitItemFn

struct TraitItemFn { ... }

An associated function within the definition of a trait.

Fields

attrs: Vec<Attribute>
sig: Signature
default: Option<Block>
semi_token: Option<Semi>

Implementations

impl Clone for TraitItemFn

fn clone(self: &Self) -> Self

impl Debug for TraitItemFn

fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result

impl Eq for TraitItemFn

impl Freeze for TraitItemFn

impl Hash for TraitItemFn

fn hash<H>(self: &Self, state: &mut H)
where
    H: Hasher

impl Parse for TraitItemFn

fn parse(input: ParseStream<'_>) -> Result<Self>

impl PartialEq for TraitItemFn

fn eq(self: &Self, other: &Self) -> bool

impl RefUnwindSafe for TraitItemFn

impl Send for TraitItemFn

impl Sync for TraitItemFn

impl ToTokens for TraitItemFn

fn to_tokens(self: &Self, tokens: &mut TokenStream)

impl Unpin for TraitItemFn

impl UnsafeUnpin for TraitItemFn

impl UnwindSafe for TraitItemFn

impl<T> Any for TraitItemFn

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for TraitItemFn

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for TraitItemFn

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for TraitItemFn

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for TraitItemFn

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Spanned for TraitItemFn

fn span(self: &Self) -> Span

impl<T> ToOwned for TraitItemFn

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for TraitItemFn

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for TraitItemFn

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for TraitItemFn

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>