Struct syn::TraitItemMacro [−][src]
pub struct TraitItemMacro {
pub attrs: Vec<Attribute>,
pub mac: Macro,
pub semi_token: Option<Semi>,
}A macro invocation within the definition of a trait.
This type is available if Syn is built with the "full" feature.
Fields
attrs: Vec<Attribute>
mac: Macro
semi_token: Option<Semi>