pub struct TraitItemMethod {
pub attrs: Vec<Attribute>,
pub sig: Signature,
pub default: Option<Block>,
pub semi_token: Option<Semi>,
}Expand description
A trait method within the definition of a trait.
This type is available only if Syn is built with the "full" feature.
Fields
attrs: Vec<Attribute>sig: Signaturedefault: Option<Block>semi_token: Option<Semi>Trait Implementations
Sourceimpl Clone for TraitItemMethod
Available on crate feature full only.
impl Clone for TraitItemMethod
Available on crate feature
full only.Sourceimpl Debug for TraitItemMethod
Available on crate feature full only.
impl Debug for TraitItemMethod
Available on crate feature
full only.Sourceimpl From<TraitItemMethod> for TraitItem
impl From<TraitItemMethod> for TraitItem
Sourcefn from(e: TraitItemMethod) -> TraitItem
fn from(e: TraitItemMethod) -> TraitItem
Converts to this type from the input type.
Sourceimpl Hash for TraitItemMethod
Available on crate feature full only.
impl Hash for TraitItemMethod
Available on crate feature
full only.Sourceimpl Parse for TraitItemMethod
impl Parse for TraitItemMethod
fn parse(input: ParseStream<'_>) -> Result<Self>
Sourceimpl PartialEq for TraitItemMethod
Available on crate feature full only.
impl PartialEq for TraitItemMethod
Available on crate feature
full only.Sourceimpl ToTokens for TraitItemMethod
impl ToTokens for TraitItemMethod
Sourcefn to_tokens(&self, tokens: &mut TokenStream)
fn to_tokens(&self, tokens: &mut TokenStream)
Sourcefn to_token_stream(&self) -> TokenStream
fn to_token_stream(&self) -> TokenStream
Sourcefn into_token_stream(self) -> TokenStreamwhere
Self: Sized,
fn into_token_stream(self) -> TokenStreamwhere
Self: Sized,
impl Eq for TraitItemMethod
Available on crate feature
full only.Auto Trait Implementations
impl Freeze for TraitItemMethod
impl RefUnwindSafe for TraitItemMethod
impl !Send for TraitItemMethod
impl !Sync for TraitItemMethod
impl Unpin for TraitItemMethod
impl UnsafeUnpin for TraitItemMethod
impl UnwindSafe for TraitItemMethod