Struct TraitItemType

struct TraitItemType { ... }

An associated type within the definition of a trait.

Fields

attrs: Vec<Attribute>
type_token: Type
ident: Ident
generics: Generics
colon_token: Option<Colon>
bounds: Punctuated<TypeParamBound, Plus>
default: Option<(Eq, Type)>
semi_token: Semi

Implementations

impl Clone for TraitItemType

fn clone(self: &Self) -> Self

impl Debug for TraitItemType

fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result

impl Eq for TraitItemType

impl Freeze for TraitItemType

impl Hash for TraitItemType

fn hash<H>(self: &Self, state: &mut H)
where
    H: Hasher

impl Parse for TraitItemType

fn parse(input: ParseStream<'_>) -> Result<Self>

impl PartialEq for TraitItemType

fn eq(self: &Self, other: &Self) -> bool

impl RefUnwindSafe for TraitItemType

impl Send for TraitItemType

impl Sync for TraitItemType

impl ToTokens for TraitItemType

fn to_tokens(self: &Self, tokens: &mut TokenStream)

impl Unpin for TraitItemType

impl UnsafeUnpin for TraitItemType

impl UnwindSafe for TraitItemType

impl<T> Any for TraitItemType

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for TraitItemType

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for TraitItemType

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for TraitItemType

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for TraitItemType

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Spanned for TraitItemType

fn span(self: &Self) -> Span

impl<T> ToOwned for TraitItemType

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for TraitItemType

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for TraitItemType

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for TraitItemType

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>