pub struct UseGroup {
pub brace_token: Brace,
pub items: Punctuated<UseTree, Comma>,
}Available on crate feature
full only.Expand description
A braced group of imports in a use item: {A, B, C}.
This type is available only if Syn is built with the "full" feature.
Fields
brace_token: Braceitems: Punctuated<UseTree, Comma>Trait Implementations
sourceimpl PartialEq<UseGroup> for UseGroup
Available on crate feature extra-traits only.
impl PartialEq<UseGroup> for UseGroup
Available on crate feature
extra-traits only.sourceimpl ToTokens for UseGroup
Available on crate feature printing only.
impl ToTokens for UseGroup
Available on crate feature
printing only.sourcefn to_tokens(&self, tokens: &mut TokenStream)
fn to_tokens(&self, tokens: &mut TokenStream)
sourcefn to_token_stream(&self) -> TokenStream
fn to_token_stream(&self) -> TokenStream
sourcefn into_token_stream(self) -> TokenStreamwhere
Self: Sized,
fn into_token_stream(self) -> TokenStreamwhere Self: Sized,
impl Eq for UseGroup
Available on crate feature
extra-traits only.Auto Trait Implementations
impl RefUnwindSafe for UseGroup
impl !Send for UseGroup
impl !Sync for UseGroup
impl Unpin for UseGroup
impl UnwindSafe for UseGroup