Struct UsePath

struct UsePath { ... }

A path prefix of imports in a use item: std::....

Fields

ident: Ident
colon2_token: PathSep
tree: Box<UseTree>

Implementations

impl Clone for UsePath

fn clone(self: &Self) -> Self

impl Debug for UsePath

fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result

impl Eq for UsePath

impl Freeze for UsePath

impl Hash for UsePath

fn hash<H>(self: &Self, state: &mut H)
where
    H: Hasher

impl PartialEq for UsePath

fn eq(self: &Self, other: &Self) -> bool

impl RefUnwindSafe for UsePath

impl Send for UsePath

impl Sync for UsePath

impl ToTokens for UsePath

fn to_tokens(self: &Self, tokens: &mut TokenStream)

impl Unpin for UsePath

impl UnsafeUnpin for UsePath

impl UnwindSafe for UsePath

impl<T> Any for UsePath

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for UsePath

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for UsePath

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for UsePath

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for UsePath

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Spanned for UsePath

fn span(self: &Self) -> Span

impl<T> ToOwned for UsePath

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for UsePath

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for UsePath

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for UsePath

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>