Crate syn [−] [src]
Structs
| AngleBracketedParameterData |
A path like |
| Attribute | |
| BareFnTy | |
| Field | |
| FnArg |
An argument in a function header. |
| FnDecl |
Header (not the body) of a function declaration. |
| Generics | |
| Ident | |
| Item | |
| Lifetime | |
| LifetimeDef | |
| MutTy | |
| ParenthesizedParameterData |
A path like |
| Path | |
| PathSegment |
A segment of a path: an identifier, an optional lifetime, and a set of types. |
| PolyTraitRef | |
| QSelf |
The explicit Self type in a "qualified path". The actual
path, including the trait and the associated item, is stored
separately. |
| TyParam | |
| TypeBinding |
Bind a type to an associated type: |
| Variant | |
| WhereBoundPredicate |
A type bound. |
| WhereClause | |
| WhereRegionPredicate |
A lifetime predicate. |
Enums
| Body | |
| FunctionRetTy | |
| MetaItem |
A compile-time attribute item. |
| Mutability | |
| PathParameters |
Parameters of a path segment. |
| TraitBoundModifier | |
| Ty | |
| TyParamBound | |
| VariantData | |
| Visibility | |
| WherePredicate |
A single predicate in a |
Functions
| parse_item | |
| parse_path | |
| parse_type | |
| parse_where_clause |