[−][src]Enum syn::AttrStyle
Distinguishes between attributes that decorate an item and attributes that are contained within an item.
This type is available if Syn is built with the "derive" or "full"
feature.
Outer attributes
#[repr(transparent)]/// # Example/** Please file an issue */
Inner attributes
#![feature(proc_macro)]//! # Example/*! Please file an issue */
Variants
OuterInner(Bang)Trait Implementations
impl Copy for AttrStyle[src]
impl Copy for AttrStyleimpl Clone for AttrStyle[src]
impl Clone for AttrStylefn clone(&self) -> AttrStyle[src]
fn clone(&self) -> AttrStylefn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl PartialEq<AttrStyle> for AttrStyle[src]
impl PartialEq<AttrStyle> for AttrStyleimpl Eq for AttrStyle[src]
impl Eq for AttrStyleimpl Hash for AttrStyle[src]
impl Hash for AttrStylefn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl Debug for AttrStyle[src]
impl Debug for AttrStyleAuto Trait Implementations