Enum Data
enum Data
The storage of a struct, enum or union data structure.
Syntax tree enum
This type is a syntax tree enum.
Variants
-
Struct(DataStruct) -
Enum(DataEnum) -
Union(DataUnion)
Implementations
impl Clone for Data
fn clone(self: &Self) -> Self
impl Debug for Data
fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result
impl Eq for Data
impl Freeze for Data
impl Hash for Data
fn hash<H>(self: &Self, state: &mut H) where H: Hasher
impl PartialEq for Data
fn eq(self: &Self, other: &Self) -> bool
impl RefUnwindSafe for Data
impl Send for Data
impl Sync for Data
impl Unpin for Data
impl UnsafeUnpin for Data
impl UnwindSafe for Data
impl<T> Any for Data
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Data
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Data
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Data
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Data
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Data
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Data
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Data
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Data
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>