Enum syn::ForeignItem [−][src]
This is supported on crate feature
full only.An item within an extern block.
This type is available only if Syn is built with the "full" feature.
Syntax tree enum
This type is a syntax tree enum.
Variants
Fn(ForeignItemFn)A foreign function in an extern block.
Static(ForeignItemStatic)A foreign static item in an extern block: static ext: u8.
Type(ForeignItemType)A foreign type in an extern block: type void.
Macro(ForeignItemMacro)A macro invocation within an extern block.
Verbatim(TokenStream)Tokens in an extern block not interpreted by Syn.