#[non_exhaustive]pub enum ForeignItem {
Fn(ForeignItemFn),
Static(ForeignItemStatic),
Type(ForeignItemType),
Macro(ForeignItemMacro),
Verbatim(TokenStream),
}Available on crate feature
full only.Expand description
An item within an extern block.
This type is available only if Syn is built with the "full" feature.
Syntax tree enum
This type is a syntax tree enum.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Fn(ForeignItemFn)
A foreign function in an extern block.
Static(ForeignItemStatic)
A foreign static item in an extern block: static ext: u8.
Type(ForeignItemType)
A foreign type in an extern block: type void.
Macro(ForeignItemMacro)
A macro invocation within an extern block.
Verbatim(TokenStream)
Tokens in an extern block not interpreted by Syn.