[−][src]Enum syn::IntSuffix
The suffix on an integer literal if any, like the u8 in 127u8.
This type is available if Syn is built with the "derive" or "full"
feature.
Variants
I8I16I32I64I128IsizeU8U16U32U64U128UsizeNoneTrait Implementations
impl Clone for IntSuffix[src]
impl Clone for IntSuffixfn clone(&self) -> IntSuffix[src]
fn clone(&self) -> IntSuffixfn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl PartialEq<IntSuffix> for IntSuffix[src]
impl PartialEq<IntSuffix> for IntSuffixfn eq(&self, other: &IntSuffix) -> bool[src]
fn eq(&self, other: &IntSuffix) -> bool#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0
[src]This method tests for !=.
impl Eq for IntSuffix[src]
impl Eq for IntSuffiximpl Hash for IntSuffix[src]
impl Hash for IntSuffixfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl Debug for IntSuffix[src]
impl Debug for IntSuffixAuto Trait Implementations