Enum Stmt
enum Stmt
A statement, usually ending in a semicolon.
Variants
-
Local(Local) A local (let) binding.
-
Item(crate::item::Item) An item definition.
-
Expr(crate::expr::Expr, Option<$crate::token::Semi>) Expression, with or without trailing semicolon.
-
Macro(StmtMacro) A macro invocation in statement position.
Syntactically it's ambiguous which other kind of statement this macro would expand to. It can be any of local variable (
let), item, or expression.
Implementations
impl Clone for Stmt
fn clone(self: &Self) -> Self
impl Debug for Stmt
fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result
impl Eq for Stmt
impl Freeze for Stmt
impl Hash for Stmt
fn hash<H>(self: &Self, state: &mut H) where H: Hasher
impl Parse for Stmt
fn parse(input: ParseStream<'_>) -> Result<Self>
impl PartialEq for Stmt
fn eq(self: &Self, other: &Self) -> bool
impl RefUnwindSafe for Stmt
impl Send for Stmt
impl Sync for Stmt
impl ToTokens for Stmt
fn to_tokens(self: &Self, tokens: &mut TokenStream)
impl Unpin for Stmt
impl UnsafeUnpin for Stmt
impl UnwindSafe for Stmt
impl<T> Any for Stmt
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Stmt
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Stmt
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Stmt
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Stmt
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Spanned for Stmt
fn span(self: &Self) -> Span
impl<T> ToOwned for Stmt
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Stmt
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Stmt
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Stmt
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>