Enum syn::TypeParamBound [−][src]
pub enum TypeParamBound {
Trait(TraitBound),
Lifetime(Lifetime),
}This is supported on crate features
full or derive only.A trait or lifetime used as a bound on a type parameter.
This type is available only if Syn is built with the "derive" or "full"
feature.
Variants
Trait(TraitBound)Lifetime(Lifetime)Trait Implementations
impl Clone for TypeParamBound[src]
impl Clone for TypeParamBound[src]This is supported on crate feature
clone-impls only.fn clone(&self) -> Self[src]
pub fn clone_from(&mut self, source: &Self)1.0.0[src]
impl Debug for TypeParamBound[src]
impl Debug for TypeParamBound[src]This is supported on crate feature
extra-traits only.impl Eq for TypeParamBound[src]
impl Eq for TypeParamBound[src]This is supported on crate feature
extra-traits only.impl From<Lifetime> for TypeParamBound[src]
impl From<Lifetime> for TypeParamBound[src]fn from(e: Lifetime) -> TypeParamBound[src]
impl From<TraitBound> for TypeParamBound[src]
impl From<TraitBound> for TypeParamBound[src]fn from(e: TraitBound) -> TypeParamBound[src]
impl Hash for TypeParamBound[src]
impl Hash for TypeParamBound[src]This is supported on crate feature
extra-traits only.impl Parse for TypeParamBound[src]
impl Parse for TypeParamBound[src]This is supported on crate feature
parsing only.fn parse(input: ParseStream<'_>) -> Result<Self>[src]
impl PartialEq<TypeParamBound> for TypeParamBound[src]
impl PartialEq<TypeParamBound> for TypeParamBound[src]This is supported on crate feature
extra-traits only.impl ToTokens for TypeParamBound[src]
impl ToTokens for TypeParamBound[src]This is supported on crate feature
printing only.fn to_tokens(&self, tokens: &mut TokenStream)[src]
pub fn to_token_stream(&self) -> TokenStream[src]
pub fn into_token_stream(self) -> TokenStream[src]