Trait Peek
trait Peek: Sealed
Types that can be parsed by looking at just one token.
Use ParseStream::peek to peek one of these types in a parse stream
without consuming it from the stream.
This trait is sealed and cannot be implemented for types outside of Syn.
Implementors
impl<F: Copy + FnOnce(TokenMarker) -> T, T: Token> Peek for Fimpl Peek for End