Struct syn::ExprGroup [−][src]
This is supported on crate feature
full only.An expression contained within invisible delimiters.
This variant is important for faithfully representing the precedence
of expressions and is related to None-delimited spans in a
TokenStream.
This type is available only if Syn is built with the "full" feature.
Fields
attrs: Vec<Attribute>group_token: Groupexpr: Box<Expr>Trait Implementations
impl Clone for ExprGroup[src]
impl Clone for ExprGroup[src]This is supported on crate feature
clone-impls only.fn clone(&self) -> Self[src]
pub fn clone_from(&mut self, source: &Self)1.0.0[src]
impl ToTokens for ExprGroup[src]
impl ToTokens for ExprGroup[src]This is supported on crate feature
printing only.fn to_tokens(&self, tokens: &mut TokenStream)[src]
pub fn to_token_stream(&self) -> TokenStream[src]
pub fn into_token_stream(self) -> TokenStream[src]