Struct ExprGroup
struct ExprGroup { ... }
An expression contained within invisible delimiters.
This variant is important for faithfully representing the precedence
of expressions and is related to None-delimited spans in a
TokenStream.
Fields
attrs: Vec<Attribute>group_token: Groupexpr: Box<Expr>
Implementations
impl Clone for ExprGroup
fn clone(self: &Self) -> Self
impl Debug for ExprGroup
fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result
impl Eq for ExprGroup
impl Freeze for ExprGroup
impl Hash for ExprGroup
fn hash<H>(self: &Self, state: &mut H) where H: Hasher
impl PartialEq for ExprGroup
fn eq(self: &Self, other: &Self) -> bool
impl RefUnwindSafe for ExprGroup
impl Send for ExprGroup
impl Sync for ExprGroup
impl ToTokens for ExprGroup
fn to_tokens(self: &Self, tokens: &mut TokenStream)
impl Unpin for ExprGroup
impl UnsafeUnpin for ExprGroup
impl UnwindSafe for ExprGroup
impl<T> Any for ExprGroup
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ExprGroup
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ExprGroup
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ExprGroup
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ExprGroup
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Spanned for ExprGroup
fn span(self: &Self) -> Span
impl<T> ToOwned for ExprGroup
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for ExprGroup
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ExprGroup
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ExprGroup
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>