Struct ExprPath
struct ExprPath { ... }
A path like std::mem::replace possibly containing generic
parameters and a qualified self-type.
A plain identifier like x is a path of length 1.
Fields
attrs: Vec<Attribute>qself: Option<QSelf>path: Path
Implementations
impl Clone for ExprPath
fn clone(self: &Self) -> Self
impl Debug for ExprPath
fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result
impl Eq for ExprPath
impl Freeze for ExprPath
impl Hash for ExprPath
fn hash<H>(self: &Self, state: &mut H) where H: Hasher
impl Parse for ExprPath
fn parse(input: ParseStream<'_>) -> Result<Self>
impl PartialEq for ExprPath
fn eq(self: &Self, other: &Self) -> bool
impl RefUnwindSafe for ExprPath
impl Send for ExprPath
impl Sync for ExprPath
impl ToTokens for ExprPath
fn to_tokens(self: &Self, tokens: &mut TokenStream)
impl Unpin for ExprPath
impl UnsafeUnpin for ExprPath
impl UnwindSafe for ExprPath
impl<T> Any for ExprPath
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ExprPath
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ExprPath
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ExprPath
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ExprPath
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Spanned for ExprPath
fn span(self: &Self) -> Span
impl<T> ToOwned for ExprPath
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for ExprPath
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ExprPath
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ExprPath
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>