Struct syn::ExprStruct [−][src]
pub struct ExprStruct {
pub attrs: Vec<Attribute>,
pub path: Path,
pub brace_token: Brace,
pub fields: Punctuated<FieldValue, Comma>,
pub dot2_token: Option<Dot2>,
pub rest: Option<Box<Expr>>,
}A struct literal expression: Point { x: 1, y: 1 }.
The rest provides the value of the remaining fields as in S { a: 1, b: 1, ..rest }.
This type is available if Syn is built with the "full" feature.
Fields
attrs: Vec<Attribute>
path: Path
brace_token: Brace
fields: Punctuated<FieldValue, Comma>
dot2_token: Option<Dot2>
rest: Option<Box<Expr>>