Struct ExprStruct
struct ExprStruct { ... }
A struct literal expression: Point { x: 1, y: 1 }.
The rest provides the value of the remaining fields as in S { a: 1, b: 1, ..rest }.
Fields
attrs: Vec<Attribute>qself: Option<QSelf>path: Pathbrace_token: Bracefields: Punctuated<FieldValue, Comma>dot2_token: Option<DotDot>rest: Option<Box<Expr>>
Implementations
impl Clone for ExprStruct
fn clone(self: &Self) -> Self
impl Debug for ExprStruct
fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result
impl Eq for ExprStruct
impl Freeze for ExprStruct
impl Hash for ExprStruct
fn hash<H>(self: &Self, state: &mut H) where H: Hasher
impl Parse for ExprStruct
fn parse(input: ParseStream<'_>) -> Result<Self>
impl PartialEq for ExprStruct
fn eq(self: &Self, other: &Self) -> bool
impl RefUnwindSafe for ExprStruct
impl Send for ExprStruct
impl Sync for ExprStruct
impl ToTokens for ExprStruct
fn to_tokens(self: &Self, tokens: &mut TokenStream)
impl Unpin for ExprStruct
impl UnsafeUnpin for ExprStruct
impl UnwindSafe for ExprStruct
impl<T> Any for ExprStruct
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ExprStruct
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ExprStruct
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ExprStruct
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ExprStruct
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Spanned for ExprStruct
fn span(self: &Self) -> Span
impl<T> ToOwned for ExprStruct
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for ExprStruct
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ExprStruct
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ExprStruct
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>