[−][src]Struct syn::Path
A path at which a named item is exported: std::collections::HashMap.
This type is available if Syn is built with the "derive" or "full"
feature.
Fields
leading_colon: Option<Colon2>segments: Punctuated<PathSegment, Colon2>Methods
impl Path[src]
pub fn parse_mod_style(input: ParseStream) -> Result<Self>[src]
Parse a Path containing no path arguments on any of its segments.
This function is available if Syn is built with the "parsing"
feature.
Example
use syn::{Path, Result, Token};
use syn::parse::{Parse, ParseStream};
// A simplified single `use` statement like:
//
// use std::collections::HashMap;
//
// Note that generic parameters are not allowed in a `use` statement
// so the following must not be accepted.
//
// use a::<b>::c;
struct SingleUse {
use_token: Token![use],
path: Path,
}
impl Parse for SingleUse {
fn parse(input: ParseStream) -> Result<Self> {
Ok(SingleUse {
use_token: input.parse()?,
path: input.call(Path::parse_mod_style)?,
})
}
}
pub fn is_ident<I>(&self, ident: I) -> bool where
Ident: PartialEq<I>, [src]
Ident: PartialEq<I>,
Determines whether this is a path of length 1 equal to the given ident.
For them to compare equal, it must be the case that:
- the path has no leading colon,
- the number of path segments is 1,
- the first path segment has no angle bracketed or parenthesized path arguments
- and the ident of the first path segment is equal to the given one.