Struct syn::Path [−][src]
pub struct Path {
pub leading_colon: Option<Colon2>,
pub segments: Punctuated<PathSegment, Colon2>,
}A path at which a named item is exported: std::collections::HashMap.
This type is available if Syn is built with the "derive" or "full"
feature.
Fields
leading_colon: Option<Colon2>
segments: Punctuated<PathSegment, Colon2>
Methods
impl Path[src]
impl Pathpub fn parse_mod_style(input: ParseStream) -> Result<Self>[src]
pub fn parse_mod_style(input: ParseStream) -> Result<Self>Parse a Path containing no path arguments on any of its segments.
This function is available if Syn is built with the "parsing"
feature.
Example
#[macro_use] extern crate syn; use syn::Path; use syn::parse::{Parse, ParseStream, Result}; // A simplified single `use` statement like: // // use std::collections::HashMap; // // Note that generic parameters are not allowed in a `use` statement // so the following must not be accepted. // // use a::<b>::c; struct SingleUse { use_token: Token![use], path: Path, } impl Parse for SingleUse { fn parse(input: ParseStream) -> Result<Self> { Ok(SingleUse { use_token: input.parse()?, path: input.call(Path::parse_mod_style)?, }) } }