[−][src]Struct syn::QSelf
The explicit Self type in a qualified path: the T in <T as Display>::fmt.
The actual path, including the trait and the associated item, is stored
separately. The position field represents the index of the associated
item qualified with this Self type.
<Vec<T> as a::b::Trait>::AssociatedItem
^~~~~~ ~~~~~~~~~~~~~~^
ty position = 3
<Vec<T>>::AssociatedItem
^~~~~~ ^
ty position = 0
This type is available if Syn is built with the "derive" or "full"
feature.
Fields
lt_token: Lt
ty: Box<Type>
position: usize
as_token: Option<As>
gt_token: Gt