Struct QSelf

struct QSelf { ... }

The explicit Self type in a qualified path: the T in <T as Display>::fmt.

The actual path, including the trait and the associated item, is stored separately. The position field represents the index of the associated item qualified with this Self type.

<Vec<T> as a::b::Trait>::AssociatedItem
 ^~~~~~    ~~~~~~~~~~~~~~^
 ty        position = 3

<Vec<T>>::AssociatedItem
 ^~~~~~   ^
 ty       position = 0

Fields

lt_token: Lt
ty: Box<Type>
position: usize
as_token: Option<As>
gt_token: Gt

Implementations

impl Clone for QSelf

fn clone(self: &Self) -> Self

impl Debug for QSelf

fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result

impl Eq for QSelf

impl Freeze for QSelf

impl Hash for QSelf

fn hash<H>(self: &Self, state: &mut H)
where
    H: Hasher

impl PartialEq for QSelf

fn eq(self: &Self, other: &Self) -> bool

impl RefUnwindSafe for QSelf

impl Send for QSelf

impl Spanned for QSelf

fn span(self: &Self) -> Span

impl Sync for QSelf

impl Unpin for QSelf

impl UnsafeUnpin for QSelf

impl UnwindSafe for QSelf

impl<T> Any for QSelf

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for QSelf

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for QSelf

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for QSelf

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for QSelf

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for QSelf

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for QSelf

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for QSelf

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for QSelf

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>