Struct syn::TraitBound
source · pub struct TraitBound {
pub paren_token: Option<Paren>,
pub modifier: TraitBoundModifier,
pub lifetimes: Option<BoundLifetimes>,
pub path: Path,
}Available on crate features
full or derive only.Expand description
A trait used as a bound on a type parameter.
This type is available only if Syn is built with the "derive" or "full"
feature.
Fields
paren_token: Option<Paren>modifier: TraitBoundModifierlifetimes: Option<BoundLifetimes>The for<'a> in for<'a> Foo<&'a T>
path: PathThe Foo<&'a T> in for<'a> Foo<&'a T>