Struct syn::TraitItemMethod [−][src]
pub struct TraitItemMethod {
pub attrs: Vec<Attribute>,
pub sig: MethodSig,
pub default: Option<Block>,
pub semi_token: Option<Semi>,
}A trait method within the definition of a trait.
This type is available if Syn is built with the "full" feature.
Fields
attrs: Vec<Attribute>
sig: MethodSig
default: Option<Block>
semi_token: Option<Semi>